use std::str::FromStr;

use serde::Deserialize;

#[derive(Debug, Default, Deserialize)]
pub(crate) struct Config {
    pub theme: Option<String>,
    pub themes: Vec<String>,
}

impl Config {
    pub fn merge(self, other: Config) -> Self {
        Self {
            theme: self.theme.or(other.theme),
            themes: if self.themes.is_empty() {
                other.themes
            } else {
                self.themes
            },
        }
    }
}

impl FromStr for Config {
    type Err = toml::de::Error;

    fn from_str(s: &str) -> Result<Self, Self::Err> {
        toml::from_str(s)
    }
}

