use std::path::{Path, MAIN_SEPARATOR_STR};

#[derive(Debug)]
pub(crate) struct Context {
    inner: tera::Context,
}

impl Context {
    pub fn new() -> Self {
        Self {
            inner: tera::Context::new(),
        }
    }

    pub fn to_inner(&self) -> &tera::Context {
        &self.inner
    }

    pub fn normalize_path<P: AsRef<Path>>(path: &P) -> String {
        path.as_ref()
            .with_extension("")
            .to_string_lossy()
            .trim()
            .split(MAIN_SEPARATOR_STR)
            .fold(String::new(), |a, b| format!("{a}.{b}"))
            .trim_matches('.')
            .to_string()
    }

    pub fn insert<P: AsRef<Path>>(&mut self, path: &P, value: &tera::Value) {
        self.inner
            .insert(Self::normalize_path(path).trim_start_matches('.'), &value);
    }

    pub fn get<P: AsRef<Path>>(&self, path: &P) -> Option<&tera::Value> {
        self.inner.get(&Self::normalize_path(path))
    }
}

